# Table of Contents

- [tech-category-modeling-guidelines](<./tech-category-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Tech Category Modeling Guidelines](<./Tech-Category-Modeling-Guidelines.md>)
  - [Definition](<./Tech-Category-Modeling-Guidelines/Definition.md>)
  - [Description](<./Tech-Category-Modeling-Guidelines/Description.md>)
  - [Guidelines and Best Practices](<./Tech-Category-Modeling-Guidelines/Guidelines-and-Best-Practices.md>)
  - [Antipatterns](<./Tech-Category-Modeling-Guidelines/Antipatterns.md>)
  - [Applicable Use Cases](<./Tech-Category-Modeling-Guidelines/Applicable-Use-Cases.md>)
  - [Insights from Tech Category Fact Sheet](<./Tech-Category-Modeling-Guidelines/Insights-from-Tech-Category-Fact-Sheet.md>)
  - [Related Information](<./Tech-Category-Modeling-Guidelines/Related-Information.md>)
